"use strict";
(function () {
    var doingRollback = _everest_backup.doingRollback, maxUploadSize = _everest_backup.maxUploadSize, pluploadArgs = _everest_backup.pluploadArgs, locale = _everest_backup.locale;
    var bodyClass = 'ebwp-is-active';
    var messageBox = document.querySelector("#everest-backup-container #message-box");
    var setMessage = function (message) {
        messageBox.innerHTML = "";
        if (!message) {
            messageBox.classList.add("hidden");
            return;
        }
        messageBox.classList.remove("hidden");
        messageBox.innerHTML = "<p><strong>" + message + "</strong></p>";
    }; // setMessage.
    var Rollback = function () {
        var confirmationWrapper = document.querySelector("#everest-backup-container .confirmation-wrapper");
        var btnRollback = document.getElementById("btn-rollback");
        btnRollback.addEventListener("click", function (event) {
            event.preventDefault();
            document.body.classList.add(bodyClass);
            confirmationWrapper.remove();
            var currentHref = window.location.href;
            window.location.replace(currentHref + "&rollback=in-progress");
        });
    };
    /**
     * Handles the restore work.
     */
    var Restore = function () {
        var uploaderUI = document.querySelector("#everest-backup-container #restore-wrapper #plupload-upload-ui");
        if (null === uploaderUI) {
            return;
        }
        var ModalContainer = document.getElementById('everest-backup-modal-wrapper');
        var LoaderWrapper = ModalContainer.querySelector('.loader-wrapper');
        var AfterRestoreDone = ModalContainer.querySelector('.after-process-complete');
        var AfterRestoreSuccess = ModalContainer.querySelector('.after-process-success');
        var dragDropArea = document.getElementById("drag-drop-area");
        var uploader = new plupload.Uploader(pluploadArgs);
        uploader.bind("Init", function (upload) {
            if (upload.features.dragdrop) {
                uploaderUI.classList.add("drag-drop");
                dragDropArea.ondragover = function () {
                    uploaderUI.classList.add("drag-over");
                };
                dragDropArea.ondragleave = function () {
                    uploaderUI.classList.remove("drag-over");
                };
                dragDropArea.ondrop = function () {
                    uploaderUI.classList.remove("drag-over");
                };
            }
            else {
                uploaderUI.classList.add("drag-drop");
            }
        }); // Uploader: Init
        uploader.init();
        uploader.bind("FilesAdded", function (upload, files) {
            var file = files[0]; // Only one file.
            if (!file) {
                return;
            }
            var maxLimit = parseInt(maxUploadSize);
            var filesize = file.size;
            var isSizeValid = 0 !== maxLimit ? maxLimit > filesize : true;
            upload.refresh();
            if (!isSizeValid) {
                setMessage(locale.fileSizeExceedMessage);
                dragDropArea.style.borderColor = "#f00";
                upload.removeFile(file);
            }
            else {
                setMessage('');
                dragDropArea.style.borderColor = "#c3c4c7";
                document.body.classList.add(bodyClass);
                upload.start();
            }
        }); // Uploader: FilesAdded
        uploader.bind('FileUploaded', function (upload, file, res) {
            LoaderWrapper.classList.add('hidden');
            AfterRestoreDone.classList.remove('hidden');
            AfterRestoreSuccess.classList.remove('hidden');
        }); // Uploader: FileUploaded
    }; // Restore.
    /**
     * After document is fully loaded.
     */
    window.addEventListener("load", function () {
        document.body.classList.remove(bodyClass);
        if (doingRollback) {
            Rollback();
        }
        else {
            Restore();
        }
    });
})();
//# sourceMappingURL=restore.js.map