<?php
/**
 * Plugin Name: Everest Backup
 * Plugin URI: https://wpeverestbackup.com/
 * Description: Everest Backup is a modern tool that will take care of your website's backups, restoration, migration and cloning.
 * Author: everestthemes
 * Author URI: https://everestthemes.com/
 * Version: 1.0.3
 * Text Domain: everest-backup
 * License: GPLv3 or later
 * License URI: LICENSE
 *
 * @package everest-backup
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! defined( 'EVEREST_BACKUP_VERSION' ) ) {

	/**
	 * Everest Backup version.
	 */
	define( 'EVEREST_BACKUP_VERSION', ( get_file_data( __FILE__, array( 'Version' => 'Version' ) )['Version'] ) );
}

if ( ! defined( 'EVEREST_BACKUP_FILE' ) ) {

	/**
	 * Everest Backup core file.
	 */
	define( 'EVEREST_BACKUP_FILE', __FILE__ );
}

if ( ! defined( 'EVEREST_BACKUP_PATH' ) ) {

	/**
	 * Path to Everest Backup plugin folder.
	 */
	define( 'EVEREST_BACKUP_PATH', trailingslashit( plugin_dir_path( EVEREST_BACKUP_FILE ) ) );
}

if ( ! defined( 'EVEREST_BACKUP_URL' ) ) {

	/**
	 * URL to Everest Backup plugin folder.
	 */
	define( 'EVEREST_BACKUP_URL', trailingslashit( plugin_dir_url( EVEREST_BACKUP_FILE ) ) );
}

if ( ! defined( 'EVEREST_BACKUP_BACKUP_FILE_EXTENSION' ) ) {

	/**
	 * Backup file extension.
	 */
	define( 'EVEREST_BACKUP_BACKUP_FILE_EXTENSION', '.ebwp' );
}

if ( ! defined( 'EVEREST_BACKUP_BACKUP_DIR_PATH' ) ) {

	/**
	 * Directory path to backups folder.
	 */
	define( 'EVEREST_BACKUP_BACKUP_DIR_PATH', wp_normalize_path( WP_CONTENT_DIR . '/ebwp-backups' ) );
}

if ( ! defined( 'EVEREST_BACKUP_HTACCESS_PATH' ) ) {

	/**
	 * Path to htaccess file.
	 */
	define( 'EVEREST_BACKUP_HTACCESS_PATH', wp_normalize_path( ABSPATH . DIRECTORY_SEPARATOR . '.htaccess' ) );
}

if ( ! defined( 'EVEREST_BACKUP_BACKUP_DIR_URL' ) ) {

	/**
	 * Directory path to backups folder.
	 */
	define( 'EVEREST_BACKUP_BACKUP_DIR_URL', wp_normalize_path( WP_CONTENT_URL . '/ebwp-backups' ) );
}

if ( ! defined( 'EVEREST_BACKUP_LOGS_KEY' ) ) {

	/**
	 * Options table option name for the logs data.
	 */
	define( 'EVEREST_BACKUP_LOGS_KEY', 'everest_backup_logs' );
}

if ( ! defined( 'EVEREST_BACKUP_SETTINGS_KEY' ) ) {

	/**
	 * Options table option name for the settings data.
	 */
	define( 'EVEREST_BACKUP_SETTINGS_KEY', 'everest_backup_settings' );
}

if ( ! defined( 'EVEREST_BACKUP_VIEWS_DIR' ) ) {

	/**
	 * Path to Everest Backup views folder.
	 */
	define( 'EVEREST_BACKUP_VIEWS_DIR', trailingslashit( EVEREST_BACKUP_PATH . 'inc/views' ) );
}

if ( ! defined( 'EVEREST_BACKUP_CONFIG_FILENAME' ) ) {

	/**
	 * FIlename of everest-backup config file.
	 */
	define( 'EVEREST_BACKUP_CONFIG_FILENAME', 'ebwp-config.json' );
}

if ( ! defined( 'EVEREST_BACKUP_DB_FILENAME' ) ) {

	/**
	 * FIlename of everest-backup database file.
	 */
	define( 'EVEREST_BACKUP_DB_FILENAME', 'ebwp-database.sql' );
}

if ( ! defined( 'EVEREST_BACKUP_AUTH_REDIRECT_URL' ) ) {

	/**
	 * API redirect url.
	 */
	define( 'EVEREST_BACKUP_AUTH_REDIRECT_URL', is_ssl() ? 'https://auth.wpeverestbackup.com' : 'http://auth.wpeverestbackup.com' );
}

if ( ! defined( 'EVEREST_BACKUP_ADDONS_JSON_URL' ) ) {

	/**
	 * Addons json file url for addons data.
	 */
	define( 'EVEREST_BACKUP_ADDONS_JSON_URL', is_ssl() ? 'https://wpeverestbackup.com/addons/addons.json' : 'http://wpeverestbackup.com/addons/addons.json' );
}

if ( ! defined( 'EVEREST_BACKUP_SIDEBAR_JSON_URL' ) ) {

	/**
	 * Sidebar json file url for sidebar data.
	 */
	define( 'EVEREST_BACKUP_SIDEBAR_JSON_URL', is_ssl() ? 'https://wpeverestbackup.com/addons/sidebar.json' : 'http://wpeverestbackup.com/addons/sidebar.json' );
}


/**
 * Bootstrap our files.
 */
require_once EVEREST_BACKUP_PATH . '/inc/require.php';

/**
 * Init our plugin.
 *
 * @return Everest_Backup
 * @since 1.0.0
 */
function everest_backup() {
	$everest_backup = Everest_Backup::init();
	return $everest_backup;
}
everest_backup();
