<?php
/**
 * Restore class for plugins folder.
 *
 * @package everest-backup
 */

namespace Everest_Backup\Modules;

use Everest_Backup\Logs;
use Everest_Backup\Traits\Restore;

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Restore class for plugins folder.
 *
 * @since 1.0.0
 */
class Restore_Plugins {

	use Restore;

	/**
	 * Start restore.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	protected static function restore() {
		$plugins = self::get_module_files( 'plugins' );

		if ( ! $plugins ) {
			return;
		}

		Logs::info( __( 'Restoring plugins.', 'everest-backup' ) );

		$filesystem = self::$filesystem;

		if ( is_array( $plugins ) && ! empty( $plugins ) ) {
			foreach ( $plugins as $plugin ) {
				$upload_to = str_replace( self::$storage_dir, self::$wp_content_dir, $plugin );

				$filesystem->move_file( $plugin, $upload_to );
			}
		}

		$ms_blogs = self::$extract->get_temp_data( 'ms_blogs' );

		if ( is_array( $ms_blogs ) && ! empty( $ms_blogs ) ) {
			foreach ( $ms_blogs as $ms_blog_id => $ms_blog ) {
				switch_to_blog( $ms_blog_id );

				update_option( 'active_plugins', $ms_blog['ActivePlugins'] ); // Reset.

				restore_current_blog();
			}
		} else {

			$config_data = self::$extract->get_temp_data( 'config_data' );

			$active_plugins = ! empty( $config_data['ActivePlugins'] ) ? $config_data['ActivePlugins'] : array();

			update_option( 'active_plugins', $active_plugins ); // Reset.
		}

		Logs::info( __( 'Plugins restored.', 'everest-backup' ) );

	}
}
