<?php
/**
 * Restore class for themes folder.
 *
 * @package everest-backup
 */

namespace Everest_Backup\Modules;

use Everest_Backup\Logs;
use Everest_Backup\Traits\Restore;

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Restore class for themes folder.
 *
 * @since 1.0.0
 */
class Restore_Themes {

	use Restore;

	/**
	 * Start restore.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	protected static function restore() {
		$themes = self::get_module_files( 'themes' );

		if ( ! $themes ) {
			return;
		}

		Logs::info( __( 'Restoring themes.', 'everest-backup' ) );

		$filesystem = self::$filesystem;

		if ( is_array( $themes ) && ! empty( $themes ) ) {
			foreach ( $themes as $theme ) {
				$upload_to = str_replace( self::$storage_dir, self::$wp_content_dir, $theme );

				$filesystem->move_file( $theme, $upload_to );
			}
		}

		$ms_blogs = self::$extract->get_temp_data( 'ms_blogs' );

		if ( is_array( $ms_blogs ) && ! empty( $ms_blogs ) ) {
			foreach ( $ms_blogs as $ms_blog_id => $ms_blog ) {
				switch_to_blog( $ms_blog_id );

				update_option( 'template', $ms_blog['Template'] );
				update_option( 'stylesheet', $ms_blog['Stylesheet'] );

				restore_current_blog();
			}
		} else {
			$config_data = self::get_config_data();
			update_option( 'template', $config_data['Template'] );
			update_option( 'stylesheet', $config_data['Stylesheet'] );
		}

		Logs::info( __( 'Themes restored.', 'everest-backup' ) );

	}

}
