<?php
/**
 * Manual backup tab contents.
 *
 * @package everest-backup
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$everest_backup_excludes = $args['backup_excludes'];

?>

<div id="message-box" class="notice notice-info hidden"></div>

<form method="post" class="postbox" id="backup-form">

	<div class="backup-additional-settings" open>

		<h2 class="title"><?php esc_html_e( 'What to ignore?', 'everest-backup' ); ?></h2>
		<p class="description"><?php esc_html_e( 'Selected items will be ignored from the backup file.', 'everest-backup' ); ?></p>

		<ul class="backup-files-wrapper">
			<?php
			if ( is_array( $everest_backup_excludes ) && ! empty( $everest_backup_excludes ) ) {
				foreach ( $everest_backup_excludes as $everest_backup_exclude_key => $everest_backup_exclude ) {
					?>
					<li title="<?php echo esc_attr( $everest_backup_exclude['description'] ); ?>">
						<div class="left">
							<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="19.437" height="13.193" viewBox="0 0 19.437 13.193">
								<defs>
									<linearGradient id="linear-gradient" x1="0.5" x2="0.5" y2="1" gradientUnits="objectBoundingBox">
										<stop offset="0" stop-color="#e81186" />
										<stop offset="1" stop-color="#0c61dd" />
									</linearGradient>
								</defs>
								<path id="Icon_awesome-folder-open" data-name="Icon awesome-folder-open" d="M19.325,12.337,16.882,16.6a2.153,2.153,0,0,1-1.865,1.091H1.519a.825.825,0,0,1-.7-1.24l2.444-4.266A2.153,2.153,0,0,1,5.129,11.1h13.5a.825.825,0,0,1,.7,1.24ZM5.129,10H16.2V8.348A1.635,1.635,0,0,0,14.578,6.7h-5.4L7.019,4.5H1.62A1.635,1.635,0,0,0,0,6.149V15.7l2.331-4.069A3.24,3.24,0,0,1,5.129,10Z" transform="translate(0 -4.5)" fill="url(#linear-gradient)" />
							</svg>

							<?php echo esc_html( $everest_backup_exclude['label'] ); ?>
						</div>
						<div class="right">
							<?php
							everest_backup_switch(
								array(
									'name'            => $everest_backup_exclude_key,
									'label_checked'   => __( 'Ignore', 'everest-backup' ),
									'label_unchecked' => __( 'Include', 'everest-backup' ),
								)
							);
							?>
						</div>
					</li>

					<?php
				}
			}
			?>

		</ul>

		<h2 class="title"><?php esc_html_e( 'Where to backup?', 'everest-backup' ); ?></h2>
		<p class="description"><?php esc_html_e( 'Select the backup storage location. Choosing “Local Web Server” will keep the backups only in the web-server/local-system.', 'everest-backup' ); ?></p>

		<ul class="backup-files-wrapper">
			<li>
				<div class="left">
					<?php esc_html_e( 'Save a copy to', 'everest-back' ); ?>
				</div>
				<div class="right">
					<label>
						<?php
						everest_backup_package_location_dropdown(
							array(
								'name' => 'save_to',
							)
						);
						?>
					</label>
				</div>
			</li>
		</ul>
	</div>

	<div class="everest-backup-btn-wrapper" id="backup-wrapper">

		<button class="button button-primary button-hero" id="btn-backup">
			<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="99" viewBox="0 0 79 74">
				<defs>
					<filter id="Ellipse_1" x="15.538" y="10.783" width="73.776" height="73.776" filterUnits="userSpaceOnUse">
						<feOffset dy="3" input="SourceAlpha" />
						<feGaussianBlur stdDeviation="6.5" result="blur" />
						<feFlood flood-opacity="0.451" />
						<feComposite operator="in" in2="blur" />
						<feComposite in="SourceGraphic" />
					</filter>
				</defs>
				<g id="backupIcon" transform="translate(-1023.774 -356.464)">
					<path id="Icon_material-storage" data-name="Icon material-storage" d="M3,60.524H62.144V46.893H3ZM8.914,50.3h5.914v6.816H8.914ZM3,6V19.631H62.144V6ZM14.829,16.223H8.914V9.408h5.914ZM3,40.078H62.144V26.447H3ZM8.914,29.854h5.914V36.67H8.914Z" transform="translate(1020.774 350.464)" fill="#fff" />
					<g transform="matrix(1, 0, 0, 1, 1023.77, 356.46)" filter="url(#Ellipse_1)">
						<circle id="Ellipse_1-2" data-name="Ellipse 1" cx="17.388" cy="17.388" r="17.388" transform="translate(35.04 27.28)" fill="#0c61dd" />
					</g>
					<path id="Icon_awesome-plus" data-name="Icon awesome-plus" d="M14.4,8.344H9.418V3.358A1.108,1.108,0,0,0,8.31,2.25H7.2A1.108,1.108,0,0,0,6.094,3.358V8.344H1.108A1.108,1.108,0,0,0,0,9.452V10.56a1.108,1.108,0,0,0,1.108,1.108H6.094v4.986A1.108,1.108,0,0,0,7.2,17.763H8.31a1.108,1.108,0,0,0,1.108-1.108V11.668H14.4a1.108,1.108,0,0,0,1.108-1.108V9.452A1.108,1.108,0,0,0,14.4,8.344Z" transform="translate(1068.444 391.129)" fill="#fff" />
				</g>
			</svg>
			<?php esc_html_e( 'Click Here To', 'everest-backup' ); ?>
			<span><?php esc_html_e( 'Backup Now!', 'everest-backup' ); ?></span>
		</button>

		<details class="card hidden" id="everest-backup-logs-container"></details>
	</div>

</form>
