<?php
/**
 * HTML content for the settings schedule backup tab.
 *
 * @package everest-backup
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$everest_backup_settings    = ! empty( $args['settings'] ) ? $args['settings'] : array();
$everest_backup_excludes    = ! empty( $args['backup_excludes'] ) ? $args['backup_excludes'] : array();
$everest_backup_cron_cycles = ! empty( $args['cron_cycles'] ) ? $args['cron_cycles'] : array();

$everest_backup_schedule_backup_enabled = isset( $everest_backup_settings['schedule_backup']['enable'] ) && $everest_backup_settings['schedule_backup']['enable'];
$everest_backup_tr_rows_class           = $everest_backup_schedule_backup_enabled ? 'schedule-backup-table-rows' : 'schedule-backup-table-rows hidden';

$everest_backup_cron_cycle_hook    = ! empty( $everest_backup_settings['schedule_backup']['cron_cycle'] ) ? $everest_backup_settings['schedule_backup']['cron_cycle'] . '_hook' : '';
$everest_backup_cron_next_schedule = wp_next_scheduled( $everest_backup_cron_cycle_hook );

?>
<form method="post" class="postbox">
	<div class="schedule-backup-wrapper">

		<p class="description"><?php esc_html_e( 'Backup your website automatically in your set schedule.', 'everest-backup' ); ?></p>

		<table class="form-table" id="schedule-backup">
			<tbody>

				<tr>
					<th scope="row"><?php esc_html_e( 'Enable', 'everest-backup' ); ?></th>
					<td>
						<label>
							<?php
							everest_backup_switch(
								array(
									'name'    => 'everest_backup_settings[schedule_backup][enable]',
									'id'      => 'enable-disable',
									'checked' => $everest_backup_schedule_backup_enabled,
								)
							);
							?>
							<span><?php esc_html_e( 'Enable/Disable schedule backup.', 'everest-backup' ); ?></span>
						</label>
					</td>
				</tr>

				<tr class="<?php echo esc_attr( $everest_backup_tr_rows_class ); ?>">
					<th scope="row"><?php esc_html_e( 'Cron Cycle', 'everest-backup' ); ?></th>
					<td>
						<label>
							<span><?php esc_html_e( 'Backup', 'everest-backup' ); ?> </span>

							<select name="everest_backup_settings[schedule_backup][cron_cycle]">
								<?php
								if ( is_array( $everest_backup_cron_cycles ) && ! empty( $everest_backup_cron_cycles ) ) {
									foreach ( $everest_backup_cron_cycles as $everest_backup_cron_cycle_key => $everest_backup_cron_cycle ) {
										?>
										<option <?php isset( $everest_backup_settings['schedule_backup']['cron_cycle'] ) && $everest_backup_settings['schedule_backup']['cron_cycle'] ? selected( $everest_backup_settings['schedule_backup']['cron_cycle'], $everest_backup_cron_cycle_key ) : ''; ?> value="<?php echo esc_attr( $everest_backup_cron_cycle_key ); ?>"><?php echo esc_html( $everest_backup_cron_cycle['display'] ); ?></option>
										<?php
									}
								}
								?>
							</select>

							<span><?php esc_html_e( 'at', 'everest-backup' ); ?> </span>

							<input type="time" value="<?php echo ! empty( $everest_backup_settings['schedule_backup']['cron_cycle_time'] ) ? esc_attr( $everest_backup_settings['schedule_backup']['cron_cycle_time'] ) : '00:00'; ?>" name="everest_backup_settings[schedule_backup][cron_cycle_time]">
						</label>
						<p><?php esc_html_e( 'Server Time:', 'everest-backup' ); ?> <code><?php echo esc_html( wp_date( 'h:i:s A e' ) ); ?></code></p>

						<p><?php esc_html_e( 'Next Backup In:', 'everest-backup' ); ?> <code><?php echo $everest_backup_cron_next_schedule ? esc_html( human_time_diff( $everest_backup_cron_next_schedule ) ) : 'N/A'; ?></code></p>
					</td>
				</tr>

				<tr class="<?php echo esc_attr( $everest_backup_tr_rows_class ); ?>">
					<th scope="row"><?php esc_html_e( 'Save To', 'everest-backup' ); ?></th>
					<td>
						<label>
							<span><?php esc_html_e( 'Save backup file to', 'everest-backup' ); ?> </span>
							<?php
							everest_backup_package_location_dropdown(
								array(
									'name'     => 'everest_backup_settings[schedule_backup][save_to]',
									'selected' => isset( $everest_backup_settings['schedule_backup']['save_to'] ) && $everest_backup_settings['schedule_backup']['save_to'] ? $everest_backup_settings['schedule_backup']['save_to'] : '',
								)
							);
							?>
							<span><?php esc_html_e( 'after schedule backup is completed.', 'everest-backup' ); ?></span>
						</label>
					</td>
				</tr>

				<tr class="<?php echo esc_attr( $everest_backup_tr_rows_class ); ?>">
					<th scope="row"><?php esc_html_e( 'Exclude', 'everest-backup' ); ?></th>
					<td>
						<details open>

							<summary style="cursor:pointer;">
								<span class="description"><?php esc_html_e( 'Selected items will be excluded from the schedule backup', 'everest-backup' ); ?></span>
							</summary>

							<table class="form-table">
								<tbody>

									<?php
									if ( is_array( $everest_backup_excludes ) && ! empty( $everest_backup_excludes ) ) {
										foreach ( $everest_backup_excludes as $everest_backup_exclude_key => $everest_backup_exclude ) {
											?>
											<tr title="<?php echo esc_attr( $everest_backup_exclude['description'] ); ?>">
												<th scope="row"><?php echo esc_html( $everest_backup_exclude['label'] ); ?></th>
												<td>
													<label>
														<?php
														everest_backup_switch(
															array(
																'name'            => "everest_backup_settings[schedule_backup][$everest_backup_exclude_key]",
																'label_checked'   => __( 'Ignore', 'everest-backup' ),
																'label_unchecked' => __( 'Include', 'everest-backup' ),
																'checked'         => isset( $everest_backup_settings['schedule_backup'][ $everest_backup_exclude_key ] ) && $everest_backup_settings['schedule_backup'][ $everest_backup_exclude_key ],
															)
														);
														?>
													</label>
												</td>
											</tr>
											<?php
										}
									}
									?>

								</tbody>
							</table>
						</details>

					</td>
				</tr>

				<tr class="<?php echo esc_attr( $everest_backup_tr_rows_class ); ?>">
					<th scope="row"><?php esc_html_e( 'Notify', 'everest-backup' ); ?></th>
					<td>
						<label>
							<?php
							everest_backup_switch(
								array(
									'name'    => 'everest_backup_settings[schedule_backup][notify]',
									'checked' => isset( $everest_backup_settings['schedule_backup']['notify'] ) && $everest_backup_settings['schedule_backup']['notify'],
								)
							);
							?>
							<span><?php esc_html_e( 'Send me an email log after schedule backup is completed.', 'everest-backup' ); ?></span>
						</label>
					</td>
				</tr>

			</tbody>
		</table>
	</div>

	<?php
	everest_backup_nonce_field( EVEREST_BACKUP_SETTINGS_KEY . '_nonce' );
	submit_button( __( 'Save Settings', 'everest-backup' ) );
	?>
</form>
<?php
