<?php
/**
 * Template file for the import/restore page..
 *
 * @package everest-backup
 */

use Everest_Backup\Modules\Restore_Tab;

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

everest_backup_render_view(
	'template-parts/modal',
	array(
		'on_success' => array(
			'title'   => __( 'Restoration Completed', 'everest-backup' ),
			'content' => function() {
				?>
				<p class="description"><?php esc_html_e( 'Please do not forget to save the permalink from sites settings.', 'everest-backup' ); ?></p>
				<a href="<?php echo esc_url( network_admin_url() ); ?>" class="button button-primary"><?php esc_html_e( 'Go To Dashboard', 'everest-backup' ); ?></a>
				<?php
			},
		),
		'on_process_msg' => __( 'Restoration/Rollback is in progress. Please do not close this window or tab.', 'everest-backup' ),
	)
);

?>
<div class="wrap">
	<hr class="wp-header-end">

	<?php
		everest_backup_render_view( 'template-parts/header' );
	?>
	<main class="everest-backup-wrapper">

		<div id="everest-backup-container">
			<div id="message-box" class="notice notice-info hidden"></div>

			<div id="restore-wrapper">

				<?php
				$everest_backup_restore_tab = new Restore_Tab();

				if ( ! everest_backup_doing_rollback() ) {
					$everest_backup_restore_tab->display();
				} else {

					$max_upload_size = everest_backup_max_upload_size();

					?>

					<div class="rollback-container card">
						<p class="notice notice-info hidden"><strong><?php esc_html_e( 'Please wait while we are rolling back your website to the previous version.', 'everest-backup' ); ?></strong></p>
						<span class="spinner"></span>

						<h2><?php esc_html_e( 'Package Information', 'everest-backup' ); ?></h2>

						<?php if ( ! empty( $args['filename'] ) ) { ?>
							<ul>
								<li><?php printf( '<strong>%1$s :</strong> %2$s', esc_html__( 'Filename', 'everest-backup' ), esc_html( $args['filename'] ) ); ?></li>
								<li><?php printf( '<strong>%1$s :</strong> %2$s', esc_html__( 'Created On', 'everest-backup' ), esc_html( wp_date( 'h:i:s A [F j, Y]', $args['time'] ) ) ); ?></li>
								<li><?php printf( '<strong>%1$s :</strong> %2$s', esc_html__( 'Size', 'everest-backup' ), esc_html( size_format( $args['size'] ) ) ); ?></li>
							</ul>

							<?php
							if ( $max_upload_size && ( $args['size'] >= $max_upload_size ) ) {
								?>
								<p class="notice notice-error"><?php printf( '<strong>%1$s :</strong> %2$s', esc_html__( 'Maximum Upload Size', 'everest-backup' ), esc_html( size_format( $max_upload_size ) ) ); ?></p>
								<p class="notice notice-error"><strong><?php esc_html_e( 'Rollback denied because package size is larger than allowed maximum upload size.', 'everest-backup' ); ?></strong></p>
								<?php
							} else {
								if ( empty( $args['rollback'] ) ) { ?>
									<div class="confirmation-wrapper">
										<p class="notice notice-warning"><strong><?php esc_html_e( 'Are you sure? It cannot be undone after rollback is started.', 'everest-backup' ); ?></strong></p>

									<a href="<?php echo esc_url( network_admin_url( '/admin.php?page=everest-backup-import' ) ); ?>" class="button-primary"><?php esc_html_e( 'Cancel', 'everest-backup' ); ?></a>
									<button class="button-secondary" id="btn-rollback" type="button"><?php esc_html_e( 'Rollback', 'everest-backup' ); ?></button>
								</div>
							<?php }
							}
							?>

					<?php } else { ?>
						<p class="notice notice-error"><strong><?php esc_html_e( 'Oops! The selected package is either broken or does not exist.', 'everest-backup' ); ?></strong></p>
						<a href="<?php echo esc_url( network_admin_url( '/admin.php?page=everest-backup-history' ) ); ?>"><span>&larr;</span> <?php esc_html_e( 'Go to history', 'everest-backup' ); ?></a>
					<?php } ?>
				</div>

				<?php } ?>

			</div>
		</div>

		<?php
		everest_backup_render_view(
			'template-parts/sidebar',
			array(
				'current_tab' => $everest_backup_restore_tab->get_current(),
			)
		);
		?>
	</main>

</div>
<?php
