<?php
/**
 * HTML content for the settings general tab.
 *
 * @package everest-backup
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$everest_backup_settings = ! empty( $args['settings'] ) ? $args['settings'] : array();

?>
<form method="post">

	<p class="description"><?php esc_html_e( 'General configuration for your Everest Backup plugin.', 'everest-backup' ); ?></p>

	<table class="form-table" id="general">
		<tbody>
			<tr>
				<th scope="row"><?php esc_html_e( 'Admin Email', 'everest-backup' ); ?></th>
				<td>
					<label>
						<input type="email" value="<?php echo esc_attr( everest_backup_get_admin_email() ); ?>" name="everest_backup_settings[general][admin_email]">
						<a href="<?php echo esc_url( add_query_arg( 'email-test', 'sending', network_admin_url( '/admin.php?page=everest-backup-settings' ) ) ); ?>" class="button button-primary"><?php esc_html_e( 'Send Test Email', 'everest-backup' ); ?></a>
						<span class="dashicons dashicons-info-outline" data-title="<?php esc_attr_e( 'Email address that will be used by Everest Backup plugin. WordPress admin email will be used as default.', 'everest-backup' ); ?>"></span>
					</label>
				</td>
			</tr>

			<tr>
				<th scope="row"><?php esc_html_e( 'Auto Remove', 'everest-backup' ); ?></th>
				<td>
					<label>
						<input type="number" value="<?php echo ! empty( $everest_backup_settings['general']['auto_remove_older_than'] ) ? absint( $everest_backup_settings['general']['auto_remove_older_than'] ) : 0; ?>" min="0" name="everest_backup_settings[general][auto_remove_older_than]">
						<span><?php esc_html_e( 'days.', 'everest-back' ); ?></span>
						<span class="dashicons dashicons-info-outline" data-title="<?php esc_attr_e( 'Auto remove backup files after defined number of days, set 0 to keep all the files.', 'everest-backup' ); ?>"></span>
					</label>
				</td>
			</tr>

			<tr>
				<th scope="row"><?php esc_html_e( 'Exclude Files', 'everest-backup' ); ?></th>
				<td>
					<label>
						<input type="text" value="<?php echo ! empty( $everest_backup_settings['general']['exclude_files_by_extension'] ) ? esc_attr( $everest_backup_settings['general']['exclude_files_by_extension'] ) : ''; ?>" placeholder="Ex: zip, lock" name="everest_backup_settings[general][exclude_files_by_extension]">
						<span class="dashicons dashicons-info-outline" data-title="<?php esc_attr_e( 'The file extension must be separated by single comma, without the dot as zip, lock', 'everest-backup' ); ?>"></span>
					</label>
				</td>
			</tr>
		</tbody>
	</table>
	<?php
	everest_backup_nonce_field( EVEREST_BACKUP_SETTINGS_KEY . '_nonce' );
	submit_button( __( 'Save Settings', 'everest-backup' ) );
	?>
</form>
